v1.0.0.post1
=============
- API_URL moved from being hardcoded in settings to .env file for the repository version
- login function extended and supports two ways of verification; either by user's credentials (login, password) or by client credentials (client_id, client_secret)
- added -dev postfix in versioning for development version
- fixed bugs with connection retries for post/get in utils
- modified repository url cause by change in repository name
- function that were moved from ResarchObject module to rohub module
    * :func:`rohub.list_valid_research_areas`
    * :func:`rohub.list_valid_publication_services`
    * :func:`rohub.list_valid_ros_types`
    * :func:`rohub.list_valid_templates`
    * :func:`rohub.list_valid_resource_types`
    * :func:`rohub.list_valid_creation_modes`
    * :func:`rohub.list_valid_access_modes`
- deleted functions
    * show_available_enums (ResearchObject module)
    * delete_folder (ResearchObject module)
    * delete_resource (ResearchObject module)
    * delete_annotation (ResearchObject module)
    * owned (rohub)
- added functions
    * :func:`rohub.resource_search_using_id`
    * :func:`rohub.resource_update_metadata`
    * :func:`rohub.resource_update_content`
    * :func:`Resource.show_metadata`
    * :func:`Resource.show_full_metadata`
    * :func:`Resource.update_metadata`
    * :func:`Resource.update_content`
    * :func:`Resource.delete`
    * :func:`Resource.assign_doi`
    * :func:`rohub.resource_assign_doi`
    * :func:`rohub.resource_load`
    * :func:`rohub.list_triple_object_classes`
    * :func:`rohub.list_custom_licenses`
    * :func:`rohub.list_valid_license_status`
    * :func:`rohub.add_custom_license`
    * :func:`rohub.update_custom_license`
    * :func:`rohub.ros_find`
    * :func:`rohub.list_my_ros`
    * :func:`ResearchObject.list_resources`
    * :func:`rohub.resource_download`
    * :func:`Resource.download`
    * :func:`rohub.users_find`
    * :func:`rohub.ros_set_publishers`
    * :func:`ResearchObject.set_publishers`
    * :func:`rohub.show_valid_type_matching_for_ros`
    * :func:`rohub.ros_list_folders`
    * :func:`ResearchObject.list_folders`
    * :func:`rohub.ros_add_external_resource`
    * :func:`rohub.organization_add`
- renamed functions
    * ros_delete_resource -> :func:`rohub.resource_delete`
    * ros_delete_folder -> :func:`rohub.folder_delete`
    * ros_delete_annotation -> :func:`rohub.annotation_delete`
    * search_ros_by_id -> :func:`rohub.ros_search_using_id`
    * ros_show_publications -> :func:`rohub.ros_list_publications`
    * ros_show_annotations -> :func:`rohub.ros_list_annotations`
    * ros_show_triples -> :func:`rohub.ros_list_triples`
    * ros_show_resources -> :func:`rohub.ros_list_resources`
    * show_available_licenses -> :func:`rohub.list_available_licenses`
    * show_valid_research_areas -> :func:`rohub.list_valid_research_areas`
    * show_valid_access_modes -> :func:`rohub.list_valid_access_modes`
    * show_valid_ros_types -> :func:`rohub.list_valid_ros_types`
    * show_valid_templates -> :func:`rohub.list_valid_templates`
    * show_valid_creation_modes -> :func:`rohub.list_valid_creation_modes`
    * show_valid_resource_types -> :func:`rohub.list_valid_resource_types`
    * show_valid_publication_services -> :func:`rohub.list_valid_publication_services`
    * show_publication -> :func:`ResearchObject.list_publications`
    * show_annotations -> :func:`ResearchObject.list_annotations`
    * show_triples -> :func:`ResearchObject.list_triples`
    * ros_show_triple_details -> :func:`rohub.ros_triple_details`
    * :func:`rohub.ros_add_funding` -> ros_set_funding (rohub), *change reversed in* :doc:`v1.0.2`
    * :func:`ResearchObject.add_funding` -> set_funding (ResearchObject module), *change reversed in* :doc:`v1.0.2`
    * ros_show_authors -> :func:`rohub.ros_list_authors`
    * show_authors -> :func:`ResearchObject.list_authors`
    * ros_show_contributors -> :func:`rohub.ros_list_contributors`
    * show_contributors -> :func:`ResearchObject.list_contributors`
    * ros_show_copyright -> :func:`rohub.ros_list_copyright`
    * show_copyright -> :func:`ResearchObject.list_copyright`
    * ros_show_funding -> ros_list_funding (rohub), *renamed again in* :doc:`v1.0.2`
    * show_funding -> list_funding (ResearchObject module), *renamed again* in :doc:`v1.0.2`
    * ros_show_license -> :func:`rohub.ros_list_license`
    * show_license -> :func:`ResearchObject.list_license`
    * zenodo_show_funders -> :func:`rohub.zenodo_list_funders`
    * zenodo_show_grants -> :func:`rohub.zenodo_list_grants`
    * add_author -> :func:`ResearchObject.set_authors`
    * ros_add_authors -> :func:`rohub.ros_set_authors`
    * ros_add_license -> :func:`rohub.ros_set_license`
    * add_license -> :func:`ResearchObject.set_license`
- new object - Resource dedicated for working with Resources
- enumerators are now being checked with different input format for user's value e.g. lower case, upper case, title as the legal values in enumerator are no longer consistent
- new dependency: pandas
- ros_list_resources displays results as Panda's DataFreame. DataFrame content and displaying sequence was adjusted.
- ros_add_author, ros_add_contributor, ros_add_copyright are now using agent parameter instead of display name or user
- traversing multiple pages fixed
- ros_list_publications displaying now storage_record_id